==> istio-model-v1alpha3-6.6.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/LoadBalancerSettingsFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface LoadBalancerSettingsFluent<A extends LoadBalancerSettingsFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildLbPolicy instead.
   * @return The buildable object.
   */
  @Deprecated
  public IsLoadBalancerSettingsLbPolicy getLbPolicy();
  public IsLoadBalancerSettingsLbPolicy buildLbPolicy();
  public A withLbPolicy(IsLoadBalancerSettingsLbPolicy lbPolicy);
  public Boolean hasLbPolicy();
  public A withLoadBalancerSettingsSimpleLbPolicy(LoadBalancerSettingsSimple loadBalancerSettingsSimpleLbPolicy);
  public LoadBalancerSettingsFluent.LoadBalancerSettingsSimpleLbPolicyNested<A> withNewLoadBalancerSettingsSimpleLbPolicy();
  public LoadBalancerSettingsFluent.LoadBalancerSettingsSimpleLbPolicyNested<A> withNewLoadBalancerSettingsSimpleLbPolicyLike(LoadBalancerSettingsSimple item);
  public A withLoadBalancerSettingsConsistentHashLbPolicy(LoadBalancerSettingsConsistentHash loadBalancerSettingsConsistentHashLbPolicy);
  public LoadBalancerSettingsFluent.LoadBalancerSettingsConsistentHashLbPolicyNested<A> withNewLoadBalancerSettingsConsistentHashLbPolicy();
  public LoadBalancerSettingsFluent.LoadBalancerSettingsConsistentHashLbPolicyNested<A> withNewLoadBalancerSettingsConsistentHashLbPolicyLike(LoadBalancerSettingsConsistentHash item);
  
  /**
   * This method has been deprecated, please use method buildLocalityLbSetting instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalityLoadBalancerSetting getLocalityLbSetting();
  public LocalityLoadBalancerSetting buildLocalityLbSetting();
  public A withLocalityLbSetting(LocalityLoadBalancerSetting localityLbSetting);
  public Boolean hasLocalityLbSetting();
  public LoadBalancerSettingsFluent.LocalityLbSettingNested<A> withNewLocalityLbSetting();
  public LoadBalancerSettingsFluent.LocalityLbSettingNested<A> withNewLocalityLbSettingLike(LocalityLoadBalancerSetting item);
  public LoadBalancerSettingsFluent.LocalityLbSettingNested<A> editLocalityLbSetting();
  public LoadBalancerSettingsFluent.LocalityLbSettingNested<A> editOrNewLocalityLbSetting();
  public LoadBalancerSettingsFluent.LocalityLbSettingNested<A> editOrNewLocalityLbSettingLike(LocalityLoadBalancerSetting item);
  public interface LoadBalancerSettingsSimpleLbPolicyNested<N> extends Nested<N>,LoadBalancerSettingsSimpleFluent<LoadBalancerSettingsFluent.LoadBalancerSettingsSimpleLbPolicyNested<N>>{
    public N and();
    public N endLoadBalancerSettingsSimpleLbPolicy();
    
  }
  public interface LoadBalancerSettingsConsistentHashLbPolicyNested<N> extends Nested<N>,LoadBalancerSettingsConsistentHashFluent<LoadBalancerSettingsFluent.LoadBalancerSettingsConsistentHashLbPolicyNested<N>>{
    public N and();
    public N endLoadBalancerSettingsConsistentHashLbPolicy();
    
  }
  public interface LocalityLbSettingNested<N> extends Nested<N>,LocalityLoadBalancerSettingFluent<LoadBalancerSettingsFluent.LocalityLbSettingNested<N>>{
    public N and();
    public N endLocalityLbSetting();
    
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/LoadBalancerSettingsFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface LoadBalancerSettingsFluent<A extends LoadBalancerSettingsFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildLbPolicy instead.
   * @return The buildable object.
   */
  @Deprecated
  public IsLoadBalancerSettingsLbPolicy getLbPolicy();
  public IsLoadBalancerSettingsLbPolicy buildLbPolicy();
  public A withLbPolicy(IsLoadBalancerSettingsLbPolicy lbPolicy);
  public Boolean hasLbPolicy();
  public A withLoadBalancerSettingsSimpleLbPolicy(LoadBalancerSettingsSimple loadBalancerSettingsSimpleLbPolicy);
  public LoadBalancerSettingsFluent.LoadBalancerSettingsSimpleLbPolicyNested<A> withNewLoadBalancerSettingsSimpleLbPolicy();
  public LoadBalancerSettingsFluent.LoadBalancerSettingsSimpleLbPolicyNested<A> withNewLoadBalancerSettingsSimpleLbPolicyLike(LoadBalancerSettingsSimple item);
  public A withLoadBalancerSettingsConsistentHashLbPolicy(LoadBalancerSettingsConsistentHash loadBalancerSettingsConsistentHashLbPolicy);
  public LoadBalancerSettingsFluent.LoadBalancerSettingsConsistentHashLbPolicyNested<A> withNewLoadBalancerSettingsConsistentHashLbPolicy();
  public LoadBalancerSettingsFluent.LoadBalancerSettingsConsistentHashLbPolicyNested<A> withNewLoadBalancerSettingsConsistentHashLbPolicyLike(LoadBalancerSettingsConsistentHash item);
  
  /**
   * This method has been deprecated, please use method buildLocalityLbSetting instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalityLoadBalancerSetting getLocalityLbSetting();
  public LocalityLoadBalancerSetting buildLocalityLbSetting();
  public A withLocalityLbSetting(LocalityLoadBalancerSetting localityLbSetting);
  public Boolean hasLocalityLbSetting();
  public LoadBalancerSettingsFluent.LocalityLbSettingNested<A> withNewLocalityLbSetting();
  public LoadBalancerSettingsFluent.LocalityLbSettingNested<A> withNewLocalityLbSettingLike(LocalityLoadBalancerSetting item);
  public LoadBalancerSettingsFluent.LocalityLbSettingNested<A> editLocalityLbSetting();
  public LoadBalancerSettingsFluent.LocalityLbSettingNested<A> editOrNewLocalityLbSetting();
  public LoadBalancerSettingsFluent.LocalityLbSettingNested<A> editOrNewLocalityLbSettingLike(LocalityLoadBalancerSetting item);
  public interface LoadBalancerSettingsSimpleLbPolicyNested<N> extends Nested<N>,LoadBalancerSettingsSimpleFluent<LoadBalancerSettingsFluent.LoadBalancerSettingsSimpleLbPolicyNested<N>>{
    public N and();
    public N endLoadBalancerSettingsSimpleLbPolicy();
    
  }
  public interface LoadBalancerSettingsConsistentHashLbPolicyNested<N> extends Nested<N>,LoadBalancerSettingsConsistentHashFluent<LoadBalancerSettingsFluent.LoadBalancerSettingsConsistentHashLbPolicyNested<N>>{
    public N and();
    public N endLoadBalancerSettingsConsistentHashLbPolicy();
    
  }
  public interface LocalityLbSettingNested<N> extends Nested<N>,LocalityLoadBalancerSettingFluent<LoadBalancerSettingsFluent.LocalityLbSettingNested<N>>{
    public N and();
    public N endLocalityLbSetting();
    
  }
  
}
